<?php  
	/*
	 * Functions for showing Google Picasa Webalbums within your Concrete 5 website
	 * within your Concrete 5 website with the use of Highslide http//:highslide.com
	 * @author Wim Bouter <wim@dewebmakers.nl>
	 */
	 
	Loader::block('library_file');	
	defined('C5_EXECUTE') or die(_("Access Denied."));
	
	class HighslideWebAlbumsBlockController extends BlockController {
 
		protected $btInterfaceWidth = 500;
		protected $btInterfaceHeight = 550;
		protected $btTable = 'btHighslideWebAlbum';
		
		public $thumb_attribute = 0;
		public $thumb_width = 70;
		public $thumb_width_crop  = 0;
		public $max_width = 800;
		public $max_width_crop = 0;
		
		public $dimming = 1;
		public $dimmingopacity = 75;
		
		public $credits = 1;
		public $credits_url = '';
		public $credits_title = '';
		public $credits_text = '';
		
		public $playback = "ORDER";	
		
		public $images = array();
		
		public $attributes = array(array('akHandle' => 'fvTitle', 'akName' => 'Title'),
								   array('akHandle' => 'fvDescription', 'akName' => 'Description'),
								   array('akHandle' => 'fvTags', 'akName' => 'Tags'),
								   array('akHandle' => 'fvFilename', 'akName' => 'Filename'),
								   array('akHandle' => 'fvSize', 'akName' => 'Size'),
								   array('akHandle' => 'fvDateAdded', 'akName' => 'Date Added'),
								   array('akHandle' => 'fvAuthor', 'akName' => 'Author'),
								   array('akHandle' => 'fvDownload', 'akName' => 'Download URL'));

								   
		public $alttags_attributes = array();
		public $selected_attributes = array();		
		
		public $alttags = 1;
		public $alttags_title = 1;
		
		public function getBlockTypeDescription() {
			return t("Shows your images (or imageset) with the use of Highslide Gallery");
		}
		
		public function getBlockTypeName() {
			return t("Highslide Web Albums");
		}
		
		public function getJavaScriptStrings() {
			return array(
				'choose-file' => t('Choose Image/File'),
				'choose-min-2' => t('Please choose at least one image.'),
				'choose-fileset' => t('Please choose a file set.')
			);
		}
	
		function __construct($obj = null) {	
			parent::__construct($obj);
			$this->db = Loader::db();
			
			$this->set('thumb_attribute', $this->thumb_attribute);
			$this->set('thumb_width', $this->thumb_width);
			$this->set('thumb_width_crop', $this->thumb_width_crop);	
			$this->set('max_width', $this->max_width);
			$this->set('max_width_crop', $this->max_width_crop);
			
			$this->set('dimming', $this->dimming);
			$this->set('dimmingopacity', $this->dimmingopacity);
			
			$this->set('credits', $this->credits);
			$this->set('credits_url', $this->credits_url);
			$this->set('credits_title', $this->credits_title);
			$this->set('credits_text', $this->credits_text);
			
			if ($this->fsID == 0) {
				$this->loadImages();
			} else {
				$this->loadFileSet();
			}
			$this->randomizeImages();
						
			$this->set('images', $this->images);
			$this->set('playback', $this->playback);
			
			$this->loadAttributes();
			$this->set('attributes', $this->attributes);
			
			$this->getAttributes();
			$this->set('alttags', $this->alttags);
			$this->set('alttags_title', $this->alttags_title);
			$this->set('alttags_attribs', @explode('%%', $this->alttags_attribs));
			$this->set('selected_attributes', $this->selected_attributes);
			
			$type = ($this->fsID > 0) ? 'FILESET' : 'CUSTOM';
			$this->set('type', $type);
			$this->set('bID', $this->bID);
		}
		
		function getFileSetName(){
			$sql = "SELECT fsName FROM FileSets WHERE fsID=".intval($this->fsID);
			return $this->db->getOne($sql); 
		}
		
		function loadAttributes(){			
			Loader::model('attribute/categories/file');			
			$otypes = FileAttributeKey::getList();
			foreach ($otypes as $type)
			{
				$types[] = array('akHandle' => $type->akHandle,
								 'akName' => $type->akName);
			}
			
			$this->attributes = @array_merge((array)$this->attributes, (array)$types);
		}
		
		function getAttributes(){									
			$attributes = @explode("%%", $this->alttags_attribs);
			$this->selected_attributes = $attributes;
		}
			
		function loadFileSet(){
			
			if (intval($this->fsID) < 1) {
				return false;
			}
			$f = Loader::helper('concrete/file');
	
			$sql = "SELECT fsf.fID, 
						   fv.fvFilename, 
						   fv.fvPrefix
				    FROM FileSetFiles AS fsf, 
						 FileVersions AS fv
				    WHERE fsf.fsID = " . $this->fsID . " 
					AND fsf.fID = fv.fID 
					AND fvIsApproved = 1";
				   
			$files = $this->db->getAll($sql); 
	
			$image = array();
			$image['groupSet'] = 0;
			$image['alttag'] = '';
			$images = array();
			$maxHeight = 0;
			foreach ($files as $file) {
				$image['fID'] = $file['fID']; 
				$image['fileName'] = $file['fvFilename'];
				$image['fullFilePath'] = $f->getFileRelativePath($file['fvPrefix'], $file['fvFilename']);
				$images[] = $image;
			}
			$this->images = $images;
		}
	
		function loadImages(){
			if(intval($this->bID)==0) $this->images=array();
			$sortChoices=array('ORDER'=>'position', 
							   'RANDOM-SET'=>'groupSet asc, position asc',
							   'RANDOM'=>'rand()');
			if( !array_key_exists($this->playback,$sortChoices) ) 
				$this->playback='ORDER';
			if(intval($this->bID)==0) return array();
			$sql = "SELECT * 
					FROM btHighslideWebAlbumImg 
					WHERE bID=".intval($this->bID).' 
					ORDER BY '.$sortChoices[$this->playback];		
			$this->images=$this->db->getAll($sql); 
		}
		
		function delete(){
			$this->db->query("DELETE FROM btHighslideWebAlbumImg WHERE bID=".intval($this->bID));		
			parent::delete();
		}
	
	
		function save($data) { 
			
			$args['playback'] = isset($data['playback']) ? trim($data['playback']) : 'ORDER';
			
			$args['thumb_attribute'] = (intval($data['thumb_attribute']) > 0)  ? intval($data['thumb_attribute']) : 0;
			
			$args['thumb_width'] = (intval($data['thumb_width']) > 0)  ? intval($data['thumb_width']) : 70;
			if ($data['thumb_width_crop'] == 1)
				$args['thumb_width_crop'] = $data['thumb_width_crop'];	
			else
				$args['thumb_width_crop'] = 0;
				
			$args['max_width'] = (intval($data['max_width']) > 0) ? intval($data['max_width']) : 800;
			
			if ($data['max_width_crop'] == 1)
				$args['max_width_crop'] = $data['max_width_crop'];	
			else
				$args['max_width_crop'] = 0;
				
			if ($data['alttags'] == 1) {
				$args['alttags'] = $data['alttags'];
				$args['alttags_title'] = $data['alttags_title'];	
				$args['alttags_attribs'] = @implode('%%', (array)$data['alttags_attribs']);	
			} else {
				$args['alttags'] = 0;
			}
			
			if (intval($data['dimming']) != 1)
				$data['dimming'] = 0;
				
			$args['dimming']  	      = $data['dimming'];			
			$args['dimmingopacity']   = $data['dimmingopacity'];
			
			if (intval($data['credits']) != 1)
				$data['credits'] = 0;
				
			$args['credits']  	      = $data['credits'];
			$args['credits_url']  	  = $data['credits_url'];
			$args['credits_title']    = $data['credits_title'];
			$args['credits_text']  	  = $data['credits_text'];				
			
			if( $data['type'] == 'FILESET' && $data['fsID'] > 0){
				$args['fsID'] = $data['fsID'];
	
				$files = $this->db->getAll("SELECT fv.fID 
											FROM FileSetFiles fsf, 
												 FileVersions fv 
										    WHERE fsf.fsID = " . $data['fsID'] ."
											AND fsf.fID = fv.fID 
											AND fvIsApproved = 1");
				
				//delete existing images
				$this->db->query("DELETE FROM btHighslideWebAlbumImg 
								  WHERE bID=".intval($this->bID));
			
			} else if( $data['type'] == 'CUSTOM' && count($data['imgFIDs']) ){
				
				$args['fsID'] = 0;
	
				//delete existing images
				$this->db->query("DELETE FROM btHighslideWebAlbumImg 
								  WHERE bID=".intval($this->bID));
				
				//loop through and add the images
				$pos=0;
				foreach($data['imgFIDs'] as $imgFID){ 
					if(intval($imgFID)==0 || $data['fileNames'][$pos]=='tempFilename') continue;
					$vals = array(intval($this->bID),intval($imgFID),intval($data['groupSet'][$pos]),$pos, addslashes($data['alttag'][$pos]));
					$this->db->query("INSERT INTO btHighslideWebAlbumImg (bID,fID,groupSet,position,alttag) values (?,?,?,?,?)",$vals);
					$pos++;
				}
			}
			
			parent::save($args);
		}				
		
		function view(){ 
		}
	
		public function on_page_view() {
			
			if (!defined('HIGHSLIDE_LOADED_JS')) {
				define('HIGHSLIDE_LOADED_JS', true);
				
				$html = Loader::helper('html');
				
				$this->addHeaderItem($html->javascript('highslide.js', 'highslide_web_albums'));
				
				$this->addHeaderItem($html->css('highslide-ie6.css', 'highslide_web_albums'));
				$this->addHeaderItem($html->css('highslide.css', 'highslide_web_albums'));
				$this->addHeaderItem($html->css('common.css', 'highslide_web_albums'));
				
				$this->addHeaderItem('<script type="text/javascript">
									  // 6058e2658aaf2fe11d7bbe3242936e32
									  hs.graphicsDir = \''.DIR_REL.'/packages/highslide_web_albums/images/\';
									  hs.transitions = [\'expand\', \'crossfade\'];
									  hs.outlineType = \'rounded-white\';
									  hs.fadeInOut = true;
									  '.(($dimming == 1)?'hs.dimmingOpacity = 0.'.$dimmingopacity:'').'
									  hs.showCredits = '.(($credits == 1)?'true':'false').'; 
									  hs.lang = { loadingText: \'Loading...\''.(($credits == 1)?', creditsText: \''.$credits_title.'\', creditsTitle:\''.$credits_text.'\'':'').' }
									  '.(($credits == 1)?'hs.creditsHref = \''.$credits_url.'\';':'').'
									  hs.addSlideshow({
										  interval: 5000,
										  repeat: false,
										  useControls: true,
										  fixedControls: \'fit\',
										  overlayOptions: { opacity: .75, position: \'bottom center\', hideOnMouseOut: true }
									  });
								      </script>');
			}
		}
		
		function randomizeImages()
		{
			if($this->playback == 'RANDOM')
			{
				shuffle($this->images);
			}
			else if($this->playback == 'RANDOM-SET')
			{
				$imageGroups=array();
				$imageGroupIds=array();
				$sortedImgs=array();
				foreach($this->images as $imgInfo){
					$imageGroups[$imgInfo['groupSet']][]=$imgInfo;
					if( !in_array($imgInfo['groupSet'],$imageGroupIds) )
						$imageGroupIds[]=$imgInfo['groupSet'];
				}
				shuffle($imageGroupIds);
				foreach($imageGroupIds as $imageGroupId){
					foreach($imageGroups[$imageGroupId] as $imgInfo)
						$sortedImgs[]=$imgInfo;
				}
				$this->images=$sortedImgs;
			}
		}
		
		function recursiveArraySearch($needle, $haystack, $index = null) 
		{ 
			$aIt = new RecursiveArrayIterator($haystack); 
			$it = new RecursiveIteratorIterator($aIt); 
			
			while($it->valid()) 
			{        
				if (((isset($index) AND ($it->key() == $index)) OR (!isset($index))) AND ($it->current() == $needle)) { 
					return $aIt->key(); 
				} 
				
				$it->next(); 
			} 
			
			return false; 
		} 
	}

?>
